@@ -1,39 +1,27 @@
 /*
- *   Copyright 2017 by Ivan Cukic <ivan.cukic (at) kde.org>
+ *   SPDX-FileCopyrightText: 2017 Ivan Cukic <ivan.cukic (at) kde.org>
  *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License or (at your option) version 3 or any later version
- *   accepted by the membership of KDE e.V. (or its successor approved
- *   by the membership of KDE e.V.), which shall act as a proxy
- *   defined in Section 14 of version 3 of the license.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "directorypairchooserwidget.h"
 #include "ui_directorypairchooserwidget.h"
 
-#include "vault.h"
 #include "backend_p.h"
+#include "vault.h"
 
 #include <QStandardPaths>
 
-class DirectoryPairChooserWidget::Private {
+class DirectoryPairChooserWidget::Private
+{
 public:
     Ui::DirectoryPairChooserWidget ui;
     const DirectoryPairChooserWidget::Flags flags;
 
     DirectoryPairChooserWidget *const q;
 
-    class DirectoryValidator {
+    class DirectoryValidator
+    {
     public:
         bool requireEmptyDirectory;
         bool requireExisting;
@@ -41,11 +29,9 @@ public:
         QString defaultPath;
         std::function<void()> update;
 
-        KMessageWidget* widget = nullptr;
+        KMessageWidget *widget = nullptr;
 
-        DirectoryValidator(bool requireEmptyDirectory, bool requireExisting,
-                           QString defaultPath,
-                           std::function<void()> update)
+        DirectoryValidator(bool requireEmptyDirectory, bool requireExisting, QString defaultPath, std::function<void()> update)
             : requireEmptyDirectory(requireEmptyDirectory)
             , requireExisting(requireExisting)
             , valid(!requireEmptyDirectory && !requireExisting)
@@ -115,30 +101,29 @@ public:
         }
     }
 
-    Private(DirectoryPairChooserWidget *parent,
-            DirectoryPairChooserWidget::Flags flags)
+    Private(DirectoryPairChooserWidget *parent, DirectoryPairChooserWidget::Flags flags)
         : flags(flags)
         , q(parent)
-        , deviceValidator(
-                flags & RequireEmptyDevice,
-                flags & RequireExistingDevice,
-                nullptr,
-                [&] { updateValidity(); }
-            )
-        , mountPointValidator(
-                flags & RequireEmptyMountPoint,
-                flags & RequireExistingMountPoint,
-                nullptr,
-                [&] { updateValidity(); }
-            )
+        , deviceValidator(flags & RequireEmptyDevice,
+                          flags & RequireExistingDevice,
+                          nullptr,
+                          [&] {
+                              updateValidity();
+                          })
+        , mountPointValidator(flags & RequireEmptyMountPoint,
+                              flags & RequireExistingMountPoint,
+                              nullptr,
+                              [&] {
+                                  updateValidity();
+                              })
         , allValid(deviceValidator.valid && mountPointValidator.valid)
     {
     }
 };
 
-DirectoryPairChooserWidget::DirectoryPairChooserWidget(
-    DirectoryPairChooserWidget::Flags flags)
-    : DialogDsl::DialogModule(false), d(new Private(this, flags))
+DirectoryPairChooserWidget::DirectoryPairChooserWidget(DirectoryPairChooserWidget::Flags flags)
+    : DialogDsl::DialogModule(false)
+    , d(new Private(this, flags))
 {
     d->ui.setupUi(this);
 
@@ -158,39 +143,31 @@ DirectoryPairChooserWidget::DirectoryPairChooserWidget(
     d->ui.messageDevice->hide();
     d->ui.messageMountPoint->hide();
 
-    connect(d->ui.editDevice, &KUrlRequester::textEdited,
-            this, [&] () {
-                d->deviceValidator.updateFor(d->ui.editDevice->url());
-            });
+    connect(d->ui.editDevice, &KUrlRequester::textEdited, this, [&]() {
+        d->deviceValidator.updateFor(d->ui.editDevice->url());
+    });
 
-    connect(d->ui.editMountPoint, &KUrlRequester::textEdited,
-            this, [&] () {
-                d->mountPointValidator.updateFor(d->ui.editMountPoint->url());
-            });
+    connect(d->ui.editMountPoint, &KUrlRequester::textEdited, this, [&]() {
+        d->mountPointValidator.updateFor(d->ui.editMountPoint->url());
+    });
 }
 
-
 DirectoryPairChooserWidget::~DirectoryPairChooserWidget()
 {
 }
 
-
 PlasmaVault::Vault::Payload DirectoryPairChooserWidget::fields() const
 {
     return {
-        { KEY_DEVICE,      d->ui.editDevice->url().toLocalFile() },
-        { KEY_MOUNT_POINT, d->ui.editMountPoint->url().toLocalFile() }
+        {KEY_DEVICE, d->ui.editDevice->url().toLocalFile()},
+        {KEY_MOUNT_POINT, d->ui.editMountPoint->url().toLocalFile()},
     };
 }
 
-
-
-void DirectoryPairChooserWidget::init(
-    const PlasmaVault::Vault::Payload &payload)
+void DirectoryPairChooserWidget::init(const PlasmaVault::Vault::Payload &payload)
 {
     if (d->flags & DirectoryPairChooserWidget::AutoFillPaths) {
-        const QString basePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)
-                + QStringLiteral("/plasma-vault");
+        const QString basePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/plasma-vault");
 
         const auto name = payload[KEY_NAME].toString();
 
@@ -213,4 +190,3 @@ void DirectoryPairChooserWidget::init(
     d->mountPointValidator.updateFor(d->ui.editMountPoint->url());
     setIsValid(d->allValid);
 }
-
